package
Version:
v0.0.0-...-ed6cb7b
Opens a new window with list of versions in this module.
Published: Jan 3, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
-
func FinalizeLogger()
-
func InitializeLogger(logPath string, maxSize, maxBackups, maxAge int, compress, debug bool)
-
func LogDebug(format string, args ...interface{})
-
func LogError(format string, args ...interface{})
-
func LogFatal(format string, args ...interface{})
-
func LogInfo(format string, args ...interface{})
-
func LogPanic(format string, args ...interface{})
-
func LogWarn(format string, args ...interface{})
func InitializeLogger(logPath string, maxSize, maxBackups, maxAge int, compress, debug bool)
InitializeLogger 로거를 초기화하고 파일 및 콘솔 출력 설정 구성
func LogDebug(format string, args ...interface{})
LogDebug DEBUG 레벨 로깅 (콘솔 출력만)
func LogError(format string, args ...interface{})
LogError ERROR 레벨 로깅
func LogFatal(format string, args ...interface{})
LogFatal FATAL 레벨 로깅
주의: os.Exit(1) 실행됨
func LogInfo(format string, args ...interface{})
LogInfo INFO 레벨 로깅
func LogPanic(format string, args ...interface{})
LogPanic PANIC 레벨 로깅
주의: Panic 발생됨
func LogWarn(format string, args ...interface{})
LogWarn WARNING 레벨 로깅
Source Files
¶
Click to show internal directories.
Click to hide internal directories.